==> digikam-4.3.0.tar.bz2: digikam-4.3.0/extra/kipi-plugins/flickrexport/kipiplugin_flickrexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flickr/23/Zooomr Exporter
Name=Flickr/23/Zooomr Exporter
Name[ast]=Esportador Flickr/23/Zooomr
Name[bg]=Изнасяне към Flickr, 23 или Zooomr
Name[bs]=Flickr/23/Zooomr Exporter
Name[ca]=Exportador a Flickr/23/Zooomr
Name[ca@valencia]=Exportador a Flickr/23/Zooomr
Name[cs]=Flickr/23/Zooomr Exporter
Name[da]=Eksport til Flickr/23/Zooomr
Name[de]=Flickr/23/Zooomr-Export
Name[el]=Εξαγωγέας Flickr/23/Zooomr
Name[en_GB]=Flickr/23/Zooomr Exporter
Name[es]=Exportar a Flickr/23/Zooomr
Name[et]=Flickr/23/Zooomr eksport
Name[eu]=Flickr/23/Zooomr esportatzailea
Name[fi]=Flickr/23/Zooomr-vienti
Name[fr]=Exportation Flickr / 23 / Zooomr
Name[ga]=Easpórtálaí Flickr/23/Zooomr
Name[gl]=Exportador a Flickr/23/Zoomr
Name[hu]=Flickr/23/Zooomr exportáló
Name[is]=Flickr/23/Zooomr útflutningur
Name[it]=Esportazione a Flickr/23/Zoomr
Name[km]=កម្មវិធី​នាំ​ចេញ Flickr/23/Zooomr
Name[lv]=Eksportēt uz Flickr/23/Zooomr
Name[nb]=Flickr/23/Zooomr-eksport
Name[nds]=Flickr/23/Zooomr-Export
Name[nl]=Flickr/23/Zooomr-export
Name[pl]=Eksporter do Flickr/23/Zooomr
Name[pt]=Exportação para o Flickr/23/Zooomr
Name[pt_BR]=Exportação para o Flickr/23/Zooomr
Name[ro]=Exportator Flickr/23/Zooomr
Name[ru]=Экспорт в Flickr, 23 и Zooomr
Name[sk]=Flickr/23/Zooomr export
Name[sl]=Izvoz v Flickr/23/Zooomr
Name[sq]=Flickr/23/Zooomr Eksportues
Name[sv]=Export till Flickr, 23 eller Zoomr
Name[th]=เครื่องมือส่งออกไปยังบริการ Flickr/23/Zooomr
Name[tr]=Flickr/23/Zooomr Servislerine Aktarıcı
Name[uk]=Експорт до Flickr/23/Zooomr
Name[x-test]=xxFlickr/23/Zooomr Exporterxx
Name[zh_CN]=Flickr/23/Zooomr 导出
Name[zh_TW]=Flickr/23/Zooomr 匯出程式
Comment=A tool to export images to remote Flickr, 23 and Zooomr web services.
Comment[ast]=Un preséu pa esportar imáxenes a servicios web remotos como Flickr, 23 y Zooomr
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Flickr, 23 или Zooomr.
Comment[bs]=Alat za izvoz slika u udaljeni Flickr, 23 i Zoomr web servis.
Comment[ca]=Una eina per exportar imatges als serveis web remots Flickr, 23 i Zooomr
Comment[ca@valencia]=Una eina per exportar imatges als serveis web remots Flickr, 23 i Zooomr
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Flickr, 23 a Zooomr.
Comment[da]=Et værktøj til at eksportere billeder til eksterne Flickr, 23 og Zooomr webtjenester.
Comment[de]=Ein Werkzeug, um Bilder zum Flickr-, 23- oder Zooomr-Webdienst zu exportieren.
Comment[el]=Εργαλείο για την εξαγωγή εικόνων στις υπηρεσίες ιστού Flickr, 23 ή Zooomr
Comment[en_GB]=A tool to export images to remote Flickr, 23 and Zooomr web services.
Comment[es]=Una herramienta para exportar imágenes a los servicios web remotos de Flickr, 23 y Zooomr.
Comment[et]=Tööriist piltide eksportimiseks Flickr, 23 ja Zooomr veebiteenusesse.
Comment[eu]=Urruneko  Flickr, 23 eta Zooomr web zerbitzuetara irudiak esportatzeko tresna
Comment[fi]=Työkalu kuvien viemiseen Flick, 23 and Zoomr -verkkopalveluihin.
Comment[fr]=Outil pour l'exportation d'images vers les services en ligne Flickr, 23 et Zooomr.
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí na seirbhísí Flickr, 23, agus Zooomr.
Comment[gl]=Unha ferramenta para exportar imaxes a servizos web remotos Flickr, 23 ou Zoomr
Comment[hu]=Egy eszköz képek exportálásához távoli Flickr, 23 és Zooomr webszolgáltatásokba.
Comment[is]=Verkfæri til að senda myndir á fjarlægar Flickr, 23 og Zooomr vefþjónustur.
Comment[it]=Uno strumento per esportare immagini ai servizi Web remoti Flickr, 23 o Zoomr.
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​សេវា​បណ្តាញ​ Flickr  23 និង​ Zooomr ​ពី​ចម្ងាយ ។
Comment[lv]=Rīks attēlu eksportēšanai uz attālinātajiem Flickr, 23 un Zooomr tīmekļa servisiem
Comment[nb]=Et verktøy for å eksportere bilder til nettjenestene Flickr, 23 eller Zooomr.
Comment[nds]=En Warktüüch, mit dat sik Biller na Flickr-, 23-, oder Zooomr-Nettdeensten exporteren laat.
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Flickr-, 23- of Zooomr-webservice te exporteren.
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnych usług sieciowych Flickr, 23 i Zooomr.
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Flickr, 23 e Zooomr.
Comment[pt_BR]=Uma ferramenta para exportar imagens para o serviço remoto da Internet Flickr, 23 e Zooomr.
Comment[ro]=O unealtă de exportat imagini către serviciile web Flickr, 23 și Zooomr.
Comment[ru]=Инструмент для экспорта изображений в веб-службы Flickr, 23 и Zooomr
Comment[sk]=Nástroj na export obrázkov do Flickr, 23 a Zoomr webových služieb
Comment[sl]=Orodje za izvoz slik v oddaljene spletne storitve Flickr, 23 in Zooomr.
Comment[sv]=Ett verktyg för att exportera bilder till Flickr, 23 eller Zoomr webbtjänster.
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Flickr, 23 และ Zooomr ทางไกล
Comment[tr]=Resimleri uzak bir Flickr, 23 ve Zooomr web servisine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Flickr, 23 або Zooomr.
Comment[x-test]=xxA tool to export images to remote Flickr, 23 and Zooomr web services.xx
Comment[zh_CN]=一个将图像导出到 Flickr、23 或 Zooomr 网络服务的工具。
Comment[zh_TW]=匯出影像到遠端 Flickr、23 和 Zooomr 網頁服務的工具。
Type=Service
Icon=kipi-flickr
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flickrexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Vardhman Jain, vardhman at gmail dot com

==> digikam-4.6.0.tar.bz2: digikam-4.6.0/extra/kipi-plugins/flickrexport/kipiplugin_flickrexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flickr/23/Zooomr Exporter
Name=Flickr/23/Zooomr Exporter
Name[ast]=Esportador Flickr/23/Zooomr
Name[bg]=Изнасяне към Flickr, 23 или Zooomr
Name[bs]=Flickr/23/Zooomr Exporter
Name[ca]=Exportador a Flickr/23/Zooomr
Name[ca@valencia]=Exportador a Flickr/23/Zooomr
Name[cs]=Flickr/23/Zooomr Exporter
Name[da]=Eksport til Flickr/23/Zooomr
Name[de]=Flickr/23/Zooomr-Export
Name[el]=Εξαγωγέας Flickr/23/Zooomr
Name[en_GB]=Flickr/23/Zooomr Exporter
Name[es]=Exportar a Flickr/23/Zooomr
Name[et]=Flickr/23/Zooomr eksport
Name[eu]=Flickr/23/Zooomr esportatzailea
Name[fi]=Flickr/23/Zooomr-vienti
Name[fr]=Exportation Flickr / 23 / Zooomr
Name[ga]=Easpórtálaí Flickr/23/Zooomr
Name[gl]=Exportador a Flickr/23/Zoomr
Name[hu]=Flickr/23/Zooomr exportáló
Name[is]=Flickr/23/Zooomr útflutningur
Name[it]=Esportazione a Flickr/23/Zoomr
Name[km]=កម្មវិធី​នាំ​ចេញ Flickr/23/Zooomr
Name[lv]=Eksportēt uz Flickr/23/Zooomr
Name[nb]=Flickr/23/Zooomr-eksport
Name[nds]=Flickr/23/Zooomr-Export
Name[nl]=Flickr/23/Zooomr-export
Name[pl]=Eksporter do Flickr/23/Zooomr
Name[pt]=Exportação para o Flickr/23/Zooomr
Name[pt_BR]=Exportar para o Flickr/23/Zooomr
Name[ro]=Exportator Flickr/23/Zooomr
Name[ru]=Экспорт в Flickr, 23 и Zooomr
Name[sk]=Flickr/23/Zooomr export
Name[sl]=Izvoz v Flickr/23/Zooomr
Name[sq]=Flickr/23/Zooomr Eksportues
Name[sv]=Export till Flickr, 23 eller Zoomr
Name[th]=เครื่องมือส่งออกไปยังบริการ Flickr/23/Zooomr
Name[tr]=Flickr/23/Zooomr Servislerine Aktarıcı
Name[uk]=Експорт до Flickr/23/Zooomr
Name[x-test]=xxFlickr/23/Zooomr Exporterxx
Name[zh_CN]=Flickr/23/Zooomr 导出
Name[zh_TW]=Flickr/23/Zooomr 匯出程式
Comment=A tool to export images to remote Flickr, 23 and Zooomr web services.
Comment[ast]=Un preséu pa esportar imáxenes a servicios web remotos como Flickr, 23 y Zooomr
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Flickr, 23 или Zooomr.
Comment[bs]=Alat za izvoz slika u udaljeni Flickr, 23 i Zoomr web servis.
Comment[ca]=Una eina per exportar imatges als serveis web remots Flickr, 23 i Zooomr
Comment[ca@valencia]=Una eina per exportar imatges als serveis web remots Flickr, 23 i Zooomr
Comment[cs]=Nástroj pro export obrázků do vzdálené webové služby Flickr, 23 a Zooomr.
Comment[da]=Et værktøj til at eksportere billeder til eksterne Flickr, 23 og Zooomr webtjenester.
Comment[de]=Ein Werkzeug, um Bilder zum Flickr-, 23- oder Zooomr-Webdienst zu exportieren.
Comment[el]=Εργαλείο για την εξαγωγή εικόνων στις υπηρεσίες ιστού Flickr, 23 ή Zooomr
Comment[en_GB]=A tool to export images to remote Flickr, 23 and Zooomr web services.
Comment[es]=Una herramienta para exportar imágenes a los servicios web remotos de Flickr, 23 y Zooomr.
Comment[et]=Tööriist piltide eksportimiseks Flickr, 23 ja Zooomr veebiteenusesse.
Comment[eu]=Urruneko  Flickr, 23 eta Zooomr web zerbitzuetara irudiak esportatzeko tresna
Comment[fi]=Kuvien vienti Flickr-, 23- ja Zoomr-verkkopalveluihin.
Comment[fr]=Outil pour l'exportation d'images vers les services en ligne Flickr, 23 et Zooomr.
Comment[ga]=Uirlis a easpórtálann íomhánna go dtí na seirbhísí Flickr, 23, agus Zooomr.
Comment[gl]=Unha ferramenta para exportar imaxes a servizos web remotos Flickr, 23 ou Zoomr
Comment[hu]=Egy eszköz képek exportálásához távoli Flickr, 23 és Zooomr webszolgáltatásokba.
Comment[is]=Verkfæri til að senda myndir á fjarlægar Flickr, 23 og Zooomr vefþjónustur.
Comment[it]=Uno strumento per esportare immagini ai servizi Web remoti Flickr, 23 o Zoomr.
Comment[km]=ឧបករណ៍​សម្រាប់​នាំ​ចេញ​រូបភាព​ទៅ​កាន់​សេវា​បណ្តាញ​ Flickr  23 និង​ Zooomr ​ពី​ចម្ងាយ ។
Comment[lv]=Rīks attēlu eksportēšanai uz attālinātajiem Flickr, 23 un Zooomr tīmekļa servisiem
Comment[nb]=Et verktøy for å eksportere bilder til nettjenestene Flickr, 23 eller Zooomr.
Comment[nds]=En Warktüüch, mit dat sik Biller na Flickr-, 23-, oder Zooomr-Nettdeensten exporteren laat.
Comment[nl]=Een hulpmiddel om afbeeldingen naar een Flickr-, 23- of Zooomr-webservice te exporteren.
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnych usług sieciowych Flickr, 23 i Zooomr.
Comment[pt]=Uma ferramenta para exportar imagens para o serviço Web remoto do Flickr, 23 e Zooomr.
Comment[pt_BR]=Ferramenta para exportar imagens para o Flickr, 23 e Zooomr.
Comment[ro]=O unealtă de exportat imagini către serviciile web Flickr, 23 și Zooomr.
Comment[ru]=Инструмент для экспорта изображений в веб-службы Flickr, 23 и Zooomr
Comment[sk]=Nástroj na export obrázkov do Flickr, 23 a Zoomr webových služieb
Comment[sl]=Orodje za izvoz slik v oddaljene spletne storitve Flickr, 23 in Zooomr.
Comment[sv]=Ett verktyg för att exportera bilder till Flickr, 23 eller Zoomr webbtjänster.
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Flickr, 23 และ Zooomr ทางไกล
Comment[tr]=Resimleri uzak bir Flickr, 23 ve Zooomr web servisine aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображень до віддаленої служби Flickr, 23 або Zooomr.
Comment[x-test]=xxA tool to export images to remote Flickr, 23 and Zooomr web services.xx
Comment[zh_CN]=一个将图像导出到 Flickr、23 或 Zooomr 网络服务的工具。
Comment[zh_TW]=匯出影像到遠端 Flickr、23 和 Zooomr 網頁服務的工具。
Type=Service
Icon=kipi-flickr
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flickrexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Vardhman Jain, vardhman at gmail dot com
